"""Common filenames for truescale Okushiri Island convergence study
Formats are given as ANUGA native netCDF where applicable.

"""
from os import sep, environ, getenv, getcwd, umask
from os.path import expanduser, basename, join
from anuga.utilities.polygon import read_polygon, plot_polygons, polygon_area, is_inside_polygon, number_mesh_triangles
import sys
from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees
from time import localtime, strftime, gmtime
from anuga.utilities.system_tools import get_user_name, get_host_name

home = join(getenv('INUNDATIONHOME'),'data', 'anuga_validation',
            'convergence_okushiri_2008') # Location of Data
user = get_user_name()
host = get_host_name()
#needed when running using mpirun, mpirun doesn't inherit umask from .bashrc
umask(002)

#-------------------
# Input file names 
#-------------------

# Given boundary wave
boundary_filename = 'okushiri_truescale_input.tms'

# Observed timeseries
validation_filename = 'okushiri_output_truescale_ch5-7-9.txt'

# Digital Elevation Model
bathymetry_filename = 'okushiri_truescale_bathymetry.pts'


#------------------------------------
# Output file names and directories 
#------------------------------------

# Model output
output_filename = 'okushiri_truescale.sww'

# Time stuff
time = strftime('%Y%m%d_%H%M%S',gmtime()) #gets time for new dir
run_time = time+'_run'

# Run parameters
finaltime=450
setup='original'

if setup =='original':
    print 'original resolution'
    base_resolution=1
    yieldstep=1
if setup =='double':
    print 'double original resolution'
    base_resolution=0.5
    yieldstep=1
if setup =='half':
    print 'half original resolution'
    base_resolution=2
    yieldstep=1
if setup =='no polygons':
    print 'half original resolution'
    base_resolution=2
    yieldstep=1
  
    
# Set anuga directories
anuga_dir = join(home,'anuga')+sep

dir_comment='_'+setup+'_'+str(user)

mesh_dir = join(anuga_dir, 'meshes')+sep
mesh_name = join(mesh_dir, 'okushiri_truescale')

polygons_dir = join(anuga_dir, 'polygons')+sep # Created with ArcGIS (csv files)

# Output locations
output_dir = join(anuga_dir, 'outputs')+sep
output_run_time_dir = output_dir+run_time+dir_comment+sep
output_run_time_dir_name = output_run_time_dir + output_filename #Used by post processing

# Gauges
gauges_dir = join(anuga_dir,'gauges')+sep
gauge_name = 'gauge_location_okushiri.csv'
gauges_dir_name = gauges_dir+gauge_name

# Vertex coordinates
vertex_filename = output_run_time_dir+setup+'vertex_coordinates.txt'

#------------------------------
# Polygon definitions
#------------------------------

poly_all = read_polygon(polygons_dir+'bounding_polygon.csv')
res_poly_all = 16000*base_resolution

#print 'Area of bounding polygon', polygon_area(poly_all)/1000000.0

poly_gulleys = read_polygon(polygons_dir+'gulleys_polygon.csv')
res_gulleys = 3.2*base_resolution

poly_island = read_polygon(polygons_dir+'island_polygon.csv')
res_island = 32*base_resolution

poly_rhs = read_polygon(polygons_dir+'rhs_polygon.csv')
res_rhs = 80*base_resolution

interior_regions = [[poly_gulleys,res_gulleys],[poly_island,res_island],
                    [poly_rhs,res_rhs]]
                    
trigs_min = number_mesh_triangles(interior_regions, poly_all, res_poly_all)

print 'min number triangles', trigs_min






